import { Steps, Card, message } from 'antd';
import React, { useState, useEffect } from 'react';
import styles from "./index.less";
import { PageContainer } from '@ant-design/pro-layout';
import StoreConfig from './components/StoreConfig';
import DeviceConfig from './components/DeviceConfig';
import FoodMenuConfig from './components/FoodMenuConfig';
import GoodsConfig from './components/GoodsConfig';
import BomConfig from './components/BomConfig';
import MaterialConfig from './components/MaterialConfig';
import ConfirmConfig from './components/ConfirmConfig';

const { Step } = Steps;

const QuickStart = () => {

    const [current, setCurrent] = useState(0);
    const [quickStartObj, setQuickStartObj] = useState({
        storeConfig: {},
        deviceConfig: {},
        foodMenuConfig: [],
    });

    const onSelectedChange = (configType, payload) => {
        const tempQuick = JSON.parse(JSON.stringify(quickStartObj));
        switch (configType) {
            case 'storeConfig':
                tempQuick.storeConfig = payload;
                break;
            case 'deviceConfig':
                tempQuick.deviceConfig = payload;
                break;
            case 'foodMenuConfig':
                tempQuick.foodMenuConfig = payload;
                break;
        }
        setQuickStartObj(tempQuick);
    }

    //将商品添加到菜谱
    const onAddGoodsToFoodMenu = (foodMenuId, goods, isAdd = true) => {
        const tempQuick = JSON.parse(JSON.stringify(quickStartObj));
        const findFoodMenu = tempQuick.foodMenuConfig.find(item => item.id === foodMenuId);
        if (isAdd && findFoodMenu) {
            findFoodMenu.goodsConfig = goods;
        } else {
            const findIndex = findFoodMenu.goodsConfig.findIndex(item => item.id === goods.id);
            if (findIndex > -1) {
                findFoodMenu.goodsConfig.splice(findIndex, 1);
            }
        }
        setQuickStartObj(tempQuick);
    }

    //配方关联商品
    const onBomRelationGoods = (goodsId, bom, isAdd = true) => {
        const tempQuick = JSON.parse(JSON.stringify(quickStartObj));
        tempQuick.foodMenuConfig.forEach(findFoodMenu => {
            const goodsInfo = findFoodMenu.goodsConfig.find(item => item.id === goodsId);
            if (goodsInfo) {
                if (isAdd) {
                    goodsInfo.bomConfig = bom;
                } else {
                    const findIndex = goodsInfo.bomConfig.findIndex(item => item.id === bom.id);
                    if (findIndex > -1) {
                        goodsInfo.bomConfig.splice(findIndex, 1);
                    }
                }
                setQuickStartObj(tempQuick);
            }
        })
    }

    //物料关联配方
    const onMaterialRelationBom = (bomId, material, isAdd = true) => {
        const tempQuick = JSON.parse(JSON.stringify(quickStartObj));
        tempQuick.foodMenuConfig.forEach(findFoodMenu => {
            findFoodMenu.goodsConfig.forEach(findGoods => {
                const findBom = findGoods.bomConfig.find(item => item.id === bomId);
                if (findBom) {
                    if (isAdd) {
                        findBom.materialConfig = material;
                    } else {
                        const findMaterialIndex = findBom.materialConfig.findIndex(item => item.id === material.id);
                        if (findMaterialIndex > -1) {
                            findBom.materialConfig.splice(findMaterialIndex, 1);
                        }
                    }
                    setQuickStartObj(tempQuick);
                }
            });
        });
    }

    //下一步
    const next = () => {
        setCurrent(current + 1);
    };

    //上一步
    const prev = () => {
        setCurrent(current - 1);
    };

    const stepsText = ['门店配置', '设备配置', '菜谱配置', '商品配置', '配方配置', '物料配置', '确认配置'];

    const stepsContent = [
        <StoreConfig storeConfig={quickStartObj.storeConfig} current={current} steps={stepsText} next={next} onSelectedChange={onSelectedChange}></StoreConfig>,
        <DeviceConfig deviceConfig={quickStartObj.deviceConfig} current={current} steps={stepsText} prev={prev} next={next} onSelectedChange={onSelectedChange} ></DeviceConfig>,
        <FoodMenuConfig foodMenuConfig={quickStartObj.foodMenuConfig} current={current} steps={stepsText} prev={prev} next={next} onSelectedChange={onSelectedChange}></FoodMenuConfig>,
        <GoodsConfig foodMenuConfig={quickStartObj.foodMenuConfig} current={current} steps={stepsText}  onAddGoodsToFoodMenu={onAddGoodsToFoodMenu} prev={prev} next={next} ></GoodsConfig>,
        <BomConfig foodMenuConfig={quickStartObj.foodMenuConfig} current={current} steps={stepsText}  prev={prev} next={next} onBomRelationGoods={onBomRelationGoods}></BomConfig>,
        <MaterialConfig foodMenuConfig={quickStartObj.foodMenuConfig} current={current} steps={stepsText}  onMaterialRelationBom={onMaterialRelationBom} prev={prev} next={next}></MaterialConfig>,
        <ConfirmConfig quickStartObj={quickStartObj} current={current} steps={stepsText} prev={prev}></ConfirmConfig>
    ];

    useEffect(() => {
        if(current > 4) {
            console.log('终极JSON对象：', JSON.stringify(quickStartObj));
        }
        console.log('JSON对象更新啦', quickStartObj);
    }, [quickStartObj]);

    return <PageContainer>
        <Card>
            <Steps current={current}>
                {stepsText.map((item) => (
                    <Step key={item} title={item} />
                ))}
            </Steps>
            <div className={styles.steps_content}>{stepsContent[current]}</div>
        </Card>
    </PageContainer>

}

export default QuickStart;